# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-02-09 08:01
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bounce',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('bounce_id', models.BigIntegerField(help_text='The ID of the bounce, as set by Postmark', unique=True, verbose_name='Bounce ID')),
                ('email_address', models.TextField(help_text='The email address the bounce is for', verbose_name='Email address')),
                ('date', models.DateTimeField(help_text='When the bounce happened', verbose_name='Date')),
                ('type_code', models.IntegerField(help_text="The type code of the bounce, as specified <a target='_blank' href='https://postmarkapp.com/developer/api/bounce-api#bounce-types'>here</a>", verbose_name='Type code')),
                ('is_inactive', models.BooleanField(help_text='If the bounce caused the email address to be deactivated', verbose_name='Is inactive')),
                ('can_activate', models.BooleanField(help_text='If the email address can be activated again', verbose_name='Can activate')),
            ],
            options={
                'ordering': ['-date'],
                'verbose_name_plural': 'bounces',
                'verbose_name': 'bounce',
            },
        ),
        migrations.CreateModel(
            name='Delivery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email_address', models.TextField(help_text='The email address the delivery is to', verbose_name='Email address')),
                ('date', models.DateTimeField(help_text='When the delivery was made', verbose_name='Date')),
            ],
            options={
                'ordering': ['-date'],
                'verbose_name_plural': 'deliveries',
                'verbose_name': 'delivery',
            },
        ),
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email_id', models.CharField(help_text="The 'Message-ID' header field of the email", max_length=255, unique=True, verbose_name='Email ID')),
                ('date', models.DateTimeField(help_text="The 'Date' header field of the email", verbose_name='Date')),
                ('sending_error', models.TextField(blank=True, help_text='String version of the exception encountered while trying to send the email', verbose_name='Sending error')),
                ('delivery_submission_date', models.DateTimeField(blank=True, help_text='When the email was submitted for delivery', null=True, verbose_name='Delivery-submission date')),
                ('delivery_email_id', models.CharField(blank=True, help_text="The 'Message-ID' header field of the email, as set by Postmark", max_length=255, null=True, unique=True, verbose_name='Delivery email ID')),
                ('delivery_error_code', models.IntegerField(blank=True, help_text="The delivery error code of the email, as specified <a target='_blank' href='https://postmarkapp.com/developer/api/overview#error-codes'>here</a>", null=True, verbose_name='Delivery error code')),
                ('delivery_message', models.CharField(blank=True, help_text='The response message from Postmark', max_length=255, verbose_name='Delivery message')),
            ],
            options={
                'ordering': ['-date'],
                'verbose_name_plural': 'emails',
                'verbose_name': 'email',
            },
        ),
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message_obj', models.BinaryField(help_text='Serialisation of the originally-sent "email.message.Message" (or a subclass) object, in pickle format', verbose_name='Message object')),
                ('message_id', models.CharField(help_text='ID used internally by the app, to match an email to the message it has been resent for, by being sent in the email header', max_length=255, unique=True, verbose_name='Message ID')),
                ('subject', models.CharField(blank=True, help_text="The 'Subject' header field of the email", max_length=255, verbose_name='Subject')),
                ('from_email', models.CharField(blank=True, help_text="The 'From' header field of the email", max_length=255, verbose_name='Sender email address')),
                ('to_emails', models.TextField(blank=True, help_text="The 'To' field of the email, with email addresses separated by commas", verbose_name='Recipient email addresses')),
                ('cc_emails', models.TextField(blank=True, help_text="The 'Cc' field of the email, with email addresses separated by commas", verbose_name="Cc'd recipient email addresses")),
                ('bcc_emails', models.TextField(blank=True, help_text="The 'Bcc' field of the email, with email addresses separated by commas", verbose_name="Bcc'd recipient email addresses")),
            ],
            options={
                'verbose_name_plural': 'messages',
                'verbose_name': 'message',
            },
        ),
        migrations.AddField(
            model_name='email',
            name='message',
            field=models.ForeignKey(help_text='The message the email is for', on_delete=django.db.models.deletion.CASCADE, related_name='emails', to='django_postmark_utils.Message', verbose_name='Message'),
        ),
        migrations.AddField(
            model_name='delivery',
            name='email',
            field=models.ForeignKey(help_text='The email the delivery is for', on_delete=django.db.models.deletion.CASCADE, related_name='deliveries', to='django_postmark_utils.Email', verbose_name='Email'),
        ),
        migrations.AddField(
            model_name='bounce',
            name='email',
            field=models.ForeignKey(help_text='The email the bounce is for', on_delete=django.db.models.deletion.CASCADE, related_name='bounces', to='django_postmark_utils.Email', verbose_name='Email'),
        ),
        migrations.AlterUniqueTogether(
            name='delivery',
            unique_together=set([('email', 'email_address')]),
        ),
    ]
